"""
Entry point to run data processing and analysis commands.
"""

# Disable numpy warnings
import warnings

import click

import analysis.forecast_twl as forecast_twl
import analysis.forecasted_storm_impacts as forecasted_storm_impacts
import analysis.observed_storm_impacts as observed_storm_impacts
import data.csv_to_geojson as csv_to_geojson
import data.parse_mat as parse_mat

warnings.simplefilter(action="ignore", category=FutureWarning)


@click.group()
def cli():
    pass


if __name__ == "__main__":
    cli.add_command(csv_to_geojson.impacts_to_geojson)
    cli.add_command(csv_to_geojson.profile_features_crest_toes_to_geojson)
    cli.add_command(csv_to_geojson.R_high_to_geojson)
    cli.add_command(csv_to_geojson.sites_csv_to_geojson)
    cli.add_command(forecast_twl.create_twl_forecast)
    cli.add_command(forecasted_storm_impacts.create_forecasted_impacts)
    cli.add_command(observed_storm_impacts.create_observed_impacts)
    cli.add_command(parse_mat.create_crest_toes)
    cli.add_command(parse_mat.create_sites_and_profiles_csv)
    cli.add_command(parse_mat.create_tides_csv)
    cli.add_command(parse_mat.create_waves_csv)
    cli()
